@@ -30,7 +30,6 @@ def enhanced_dir(arg, categorize=True, show_types=False, checks=False, interface
     if interfaces_and_types:
         import collections.abc
         import types
-        import typing
         collections_abc = {*()}
         for i in dir(collections.abc):
             try:
@@ -47,15 +46,6 @@ def enhanced_dir(arg, categorize=True, show_types=False, checks=False, interface
             except:
                 pass
         return_list.append({'types': types_})
-        typing_ = {*()}
-        for i in dir(typing):
-            try:
-                if isinstance(arg, eval(f'typing.{i}')):
-                    typing_.add(i)
-            except:
-                pass
-        return_list.append({'typing': typing_})
-
     if checks:
         checks_ = {}
         try:
@@ -94,10 +84,6 @@ def enhanced_dir(arg, categorize=True, show_types=False, checks=False, interface
 
 
 def two_way(operation, opposite=False, iterators=False, print_width=120, p=False):
-    """
-    two_way('+')
-    two_way('+', opposite=True)
-    """
     import warnings
     warnings.filterwarnings("ignore")
     import re, keyword
@@ -187,10 +173,6 @@ def two_way(operation, opposite=False, iterators=False, print_width=120, p=False
 
 
 def operator_check(left_argument, right_argument, show_failed=False, print_width=120, p=False):
-    """
-    operator_check(1, 2)
-    """
-
     import warnings
     warnings.filterwarnings("ignore")
     failed = set()
@@ -242,32 +224,15 @@ external_checks = {'imports': 'from collections import Counter, namedtuple, defa
                                'SimpleNamespace']}
 
 
-def argument_inspector(arg, lib=None, no_of_arguments=2, p=False, print_width=120, show_output=True):
-    """
-    argument_inspector('int')
-    argument_inspector('Fraction', lib='fractions')
-    """
+def argument_inspector(arg, no_of_arguments=2, p=False, print_width=120):
     from collections import defaultdict
     import warnings
     warnings.filterwarnings("ignore")
-    if show_output:
-        rtrnd_dct = defaultdict(dict)
-    else:
-        rtrnd_dct = defaultdict(set)
-
-    if lib:
-        try:
-            exec(f'from {lib} import {arg}')
-        except:
-            pass
-
+    rtrnd_dct = defaultdict(set)
     if no_of_arguments >= 0:
         try:
             x = eval(f'{arg}()')
-            if show_output:
-                rtrnd_dct[0].update({True: x})
-            else:
-                rtrnd_dct[0].add(True)
+            rtrnd_dct[0].add(True)
         except:
             pass
 
@@ -276,19 +241,13 @@ def argument_inspector(arg, lib=None, no_of_arguments=2, p=False, print_width=12
         for i in enhanced_dir.extended_builtins + enhanced_dir.inspection_arguments:
             try:
                 x = eval(f'{arg}({i})')
-                if show_output:
-                    rtrnd_dct[1].update({i: x})
-                else:
-                    rtrnd_dct[1].add(i)
+                rtrnd_dct[1].add(i)
             except:
                 pass
 
             try:
                 x = eval(f'{arg}({i}())')
-                if show_output:
-                    rtrnd_dct[1].update({f'{i}()': x})
-                else:
-                    rtrnd_dct[1].add(f'{i}()')
+                rtrnd_dct[1].add(f'{i}()')
             except:
                 pass
 
@@ -297,37 +256,25 @@ def argument_inspector(arg, lib=None, no_of_arguments=2, p=False, print_width=12
             for j in enhanced_dir.extended_builtins + enhanced_dir.inspection_arguments:
                 try:
                     x = eval(f'{arg}({i}, {j})')
-                    if show_output:
-                        rtrnd_dct[2].update({(i, j): x})
-                    else:
-                        rtrnd_dct[2].add((i, j))
+                    rtrnd_dct[2].add((i, j))
                 except:
                     pass
 
                 try:
                     x = eval(f'{arg}({i}(), {j}())')
-                    if show_output:
-                        rtrnd_dct[2].update({(f'{i}()', f'{j}()'): x})
-                    else:
-                        rtrnd_dct[2].add((f'{i}()', f'{j}()'))
+                    rtrnd_dct[2].add((f'{i}()', f'{j}()'))
                 except:
                     pass
 
                 try:
                     x = eval(f'{arg}({i}(), {j})')
-                    if show_output:
-                        rtrnd_dct[2].update({(f'{i}()', j): x})
-                    else:
-                        rtrnd_dct[2].add((f'{i}()', j))
+                    rtrnd_dct[2].add((f'{i}()', j))
                 except:
                     pass
 
                 try:
                     x = eval(f'{arg}({i}, {j}())')
-                    if show_output:
-                        rtrnd_dct[2].update({(i, f'{j}()'): x})
-                    else:
-                        rtrnd_dct[2].add((i, f'{j}()'))
+                    rtrnd_dct[2].add((i, f'{j}()'))
                 except:
                     pass
 
@@ -361,73 +308,49 @@ def argument_inspector(arg, lib=None, no_of_arguments=2, p=False, print_width=12
                 for k in enhanced_dir.extended_builtins + enhanced_dir.inspection_arguments:
                     try:
                         x = eval(f'{arg}({i}, {j}, {k})')
-                        if show_output:
-                            rtrnd_dct[3].update({(i, j, k): x})
-                        else:
-                            rtrnd_dct[3].add((i, j, k))
+                        rtrnd_dct[3].add((i, j, k))
                     except:
                         pass
 
                     try:
                         x = eval(f'{arg}({i}, {j}, {k}())')
-                        if show_output:
-                            rtrnd_dct[3].update({(i, j, f'{k}()'): x})
-                        else:
-                            rtrnd_dct[3].add((i, j, f'{k}()'))
+                        rtrnd_dct[3].add((i, j, f'{k}()'))
                     except:
                         pass
 
                     try:
                         x = eval(f'{arg}({i}, {j}(), {k})')
-                        if show_output:
-                            rtrnd_dct[3].update({(i, f'{j}()', k): x})
-                        else:
-                            rtrnd_dct[3].add((i, f'{j}()', k))
+                        rtrnd_dct[3].add((i, f'{j}()', k))
                     except:
                         pass
 
                     try:
                         x = eval(f'{arg}({i}, {j}(), {k}())')
-                        if show_output:
-                            rtrnd_dct[3].update({(i, f'{j}()', f'{k}()'): x})
-                        else:
-                            rtrnd_dct[3].add((i, f'{j}()', f'{k}()'))
+                        rtrnd_dct[3].add((i, f'{j}()', f'{k}()'))
                     except:
                         pass
 
                     try:
                         x = eval(f'{arg}({i}(), {j}, {k})')
-                        if show_output:
-                            rtrnd_dct[3].update({(f'{i}()', j, k): x})
-                        else:
-                            rtrnd_dct[3].add((f'{i}()', j, k))
+                        rtrnd_dct[3].add((f'{i}()', j, k))
                     except:
                         pass
 
                     try:
                         x = eval(f'{arg}({i}(), {j}, {k}())')
-                        if show_output:
-                            rtrnd_dct[3].update({(f'{i}()', j, f'{k}()'): x})
-                        else:
-                            rtrnd_dct[3].add((f'{i}()', j, f'{k}()'))
+                        rtrnd_dct[3].add((f'{i}()', j, f'{k}()'))
                     except:
                         pass
 
                     try:
                         x = eval(f'{arg}({i}(), {j}(), {k})')
-                        if show_output:
-                            rtrnd_dct[3].update({(f'{i}()', f'{j}()', k): x})
-                        else:
-                            rtrnd_dct[3].add((f'{i}()', f'{j}()', k))
+                        rtrnd_dct[3].add((f'{i}()', f'{j}()', k))
                     except:
                         pass
 
                     try:
                         x = eval(f'{arg}({i}(), {j}(), {k}())')
-                        if show_output:
-                            rtrnd_dct[3].update({(f'{i}()', f'{j}()', f'{k}()'): x})
-                        else:
-                            rtrnd_dct[3].add((f'{i}()', f'{j}()', f'{k}()'))
+                        rtrnd_dct[3].add((f'{i}()', f'{j}()', f'{k}()'))
                     except:
                         pass
 
@@ -438,15 +361,6 @@ def argument_inspector(arg, lib=None, no_of_arguments=2, p=False, print_width=12
         return rtrnd_dct
 
 
-inspection_arguments = [1, 0, 1.2, 'abc', '1', '0', '1.2', '1/2', {1, 2, 3}, {'a': 1, 'b': 2}, (1, 2, 3),
-                        [(2, 5), (3, 2)], [1, 2, 3], [1, 0, 1, 0],
-                        {'a', 'b', 'c'}, ('a', 'b', 'c'), ['a', 'b', 'c'], 1 + 2j,
-                        b'2', b'a', bytearray(1), frozenset({1, 2, 3}), frozenset({'a', 'b', 'c'}),
-                        (lambda x: x < 5), range(2), enumerate('a'), '(iter([1, 2, 3]))', '(iter(reversed([1, 2, 3])))',
-                        '(iter(range(5)))',
-                        '(iter({1, 2, 3}))', "(iter('abc'))", '(iter((1, 2, 3)))', "(iter({'a': 1, 'b': 2}.items()))",
-                        "(iter(zip((0, 1, 2), 'abc')))",
-                        "(iter({'a': 1, 'b': 2}.keys()))", "(iter({'a': 1, 'b': 2}.values()))",
-                        ({'a': 1, 'b': 2}.keys()),
-                        ({'a': 1, 'b': 2}.values()), ({'a': 1, 'b': 2}.items()), "(iter(b'2'))", "(iter(b'a'))",
-                        '(iter(bytearray(1)))']
+inspection_arguments = [1, 1.2, 'abc', '1', '1.2', '1/2', {1, 2, 3}, {'a': 1, 'b': 2}, (1, 2, 3), [1, 2, 3],
+                        {'a', 'b', 'c'}, ('a', 'b', 'c'), ['a', 'b', 'c'], 1 + 2j, b'2', b'a', bytearray(1),
+                        frozenset({1, 2, 3}), frozenset({'a', 'b', 'c'})]
